Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(821)

Unified Diff: chrome/browser/ui/browser.cc

Issue 7013001: Rename BookmarksTabHelper to BookmarkTabHelper. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 9 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/browser.h ('k') | chrome/browser/ui/tab_contents/tab_contents_wrapper.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/browser.cc
diff --git a/chrome/browser/ui/browser.cc b/chrome/browser/ui/browser.cc
index ab070468a2c4af35cf506ab61132d454f685b37b..2095fcfdf402f06deb0e077ea86422b033056142 100644
--- a/chrome/browser/ui/browser.cc
+++ b/chrome/browser/ui/browser.cc
@@ -75,7 +75,7 @@
#include "chrome/browser/tabs/tab_finder.h"
#include "chrome/browser/tabs/tab_strip_model.h"
#include "chrome/browser/ui/blocked_content/blocked_content_tab_helper.h"
-#include "chrome/browser/ui/bookmarks/bookmarks_tab_helper.h"
+#include "chrome/browser/ui/bookmarks/bookmark_tab_helper.h"
#include "chrome/browser/ui/browser_list.h"
#include "chrome/browser/ui/browser_tab_restore_service_delegate.h"
#include "chrome/browser/ui/browser_window.h"
@@ -3478,7 +3478,7 @@ TabContentsWrapper* Browser::GetConstrainingContentsWrapper(
}
///////////////////////////////////////////////////////////////////////////////
// Browser, BookmarksTabHelperDelegate implementation:
void Browser::URLStarredChanged(TabContentsWrapper* source, bool starred) {
if (source == GetSelectedTabContentsWrapper())
@@ -3885,7 +3885,7 @@ void Browser::UpdateCommandsForTabState() {
// Page-related commands
window_->SetStarredState(
- current_tab_wrapper->bookmarks_tab_helper()->is_starred());
+ current_tab_wrapper->bookmark_tab_helper()->is_starred());
command_updater_.UpdateCommandEnabled(IDC_VIEW_SOURCE,
current_tab->controller().CanViewSource());
command_updater_.UpdateCommandEnabled(IDC_EMAIL_PAGE_LOCATION,
@@ -4384,7 +4384,7 @@ void Browser::SetAsDelegate(TabContentsWrapper* tab, Browser* delegate) {
// ...and all the helpers.
tab->blocked_content_tab_helper()->set_delegate(delegate);
- tab->bookmarks_tab_helper()->set_delegate(delegate);
+ tab->bookmark_tab_helper()->set_delegate(delegate);
tab->search_engine_tab_helper()->set_delegate(delegate);
}
« no previous file with comments | « chrome/browser/ui/browser.h ('k') | chrome/browser/ui/tab_contents/tab_contents_wrapper.h » ('j') | no next file with comments »
@@ -3478,7 +3478,7 @@ TabContentsWrapper* Browser::GetConstrainingContentsWrapper(
}
///////////////////////////////////////////////////////////////////////////////
-// Browser, BookmarksTabHelperDelegate implementation:
+// Browser, BookmarkTabHelperDelegate implementation:
void Browser::URLStarredChanged(TabContentsWrapper* source, bool starred) {
if (source == GetSelectedTabContentsWrapper())

Powered by Google App Engine
This is Rietveld 408576698